docker_tags_getter
==================

docker_tags_getter is the application that will help you to get tags from yours docker repository.

Author
======

Kostiantyn Klochko (c) 2023

License
=======

Under the GNU Lesser General Public License v3.0 or later.

